==> ideaIC-163.13906.16-sources.jar: com/intellij/openapi/vcs/changes/patch/PatchFileDropHandler.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.openapi.vcs.changes.patch;

import com.intellij.ide.dnd.FileCopyPasteUtil;
import com.intellij.openapi.editor.CustomFileDropHandler;
import com.intellij.openapi.editor.Editor;
import com.intellij.openapi.project.Project;
import org.jetbrains.annotations.NotNull;

import java.awt.datatransfer.Transferable;
import java.io.File;
import java.util.List;

public class PatchFileDropHandler extends CustomFileDropHandler {

  @Override
  public boolean canHandle(@NotNull Transferable t, Editor editor) {
    List<File> list = FileCopyPasteUtil.getFileList(t);
    if (list == null || list.size() != 1) return false;
    return PatchFileType.isPatchFile(list.get(0));
  }

  @Override
  public boolean handleDrop(@NotNull Transferable t, Editor editor, @NotNull final Project project) {
    List<File> list = FileCopyPasteUtil.getFileList(t);
    if (list == null || list.size() != 1) return false;
    return ApplyPatchAction.showAndGetApplyPatch(project, list.get(0));
  }
}

==> ideaIC-2018.3.3-sources.jar: com/intellij/openapi/vcs/changes/patch/PatchFileDropHandler.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.openapi.vcs.changes.patch;

import com.intellij.ide.dnd.FileCopyPasteUtil;
import com.intellij.openapi.editor.CustomFileDropHandler;
import com.intellij.openapi.editor.Editor;
import com.intellij.openapi.project.Project;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.awt.datatransfer.Transferable;
import java.io.File;
import java.util.List;

public class PatchFileDropHandler extends CustomFileDropHandler {

  @Override
  public boolean canHandle(@NotNull Transferable t, @Nullable Editor editor) {
    List<File> list = FileCopyPasteUtil.getFileList(t);
    if (list == null || list.size() != 1) return false;
    return PatchFileType.isPatchFile(list.get(0));
  }

  @Override
  public boolean handleDrop(@NotNull Transferable t, @Nullable Editor editor, @NotNull final Project project) {
    List<File> list = FileCopyPasteUtil.getFileList(t);
    if (list == null || list.size() != 1) return false;
    return ApplyPatchAction.showAndGetApplyPatch(project, list.get(0));
  }
}
